# Drone Kaniko

A thin shim-wrapper around the official [Google Kaniko](https://cloud.google.com/blog/products/gcp/introducing-kaniko-build-container-images-in-kubernetes-and-google-container-builder-even-without-root-access) Docker image to make it behave like the [Drone Docker plugin](http://plugins.drone.io/drone-plugins/drone-docker/).

Based on the original [drone-kaniko](https://github.com/banzaicloud/drone-kaniko) by [Banzai Cloud](https://github.com/banzaicloud)
Modified by [ODIT.Services](https://odit.services) to enable local builds to tar.


## Settings

* `registry`: Your registry (defaults to docker hub)
* `repo`: The image repository
* `tags`: The image tags (as a simple string or an array)
* `username`: Username for the chosen docker registry
* `password`: Password for the chosen docker registry
* `nopush`: Disable Pushing to registry (boolean)
* `tarpath`: Export the image to tar (relative path)
* `cache`: Use cached intermediate containers (boolean)
* `skip_tls_verify`: Skip SSL/TLS certificate verification (boolean)
* `build_args`: Pass custom arguments to docker build
* `build_args_from_env`: Pass the envvars as custom arguments to docker build
* `json_key`: Provide registry auth data via json_key (mostly for gcr)
* `auto_tag`: generate tag names automatically based on git branch and git tag

## Examples

```yaml
kind: pipeline
name: default

steps:
- name: publish
  image: registry.odit.services/library/drone-kaniko
  settings:
    registry: registry.example.com # if not provided index.docker.io is supposed
    repo: registry.example.com/example-project
    tags: ${DRONE_COMMIT_SHA}
    cache: true
    skip_tls_verify: false # set to true for testing registries ONLY with self-signed certs
    build_args:
    - COMMIT_SHA=${DRONE_COMMIT_SHA}
    - COMMIT_AUTHOR_EMAIL=${DRONE_COMMIT_AUTHOR_EMAIL}
    username:
      from_secret: docker-username
    password:
      from_secret: docker-password
```

Pushing to GCR:

```yaml
kind: pipeline
name: default

steps:
- name: publish
  image: registry.odit.services/library/drone-kaniko
  settings:
    registry: gcr.io
    repo: example.com/example-project
    tags: ${DRONE_COMMIT_SHA}
    cache: true
    json_key:
      from_secret: google-application-credentials
```

## Use `.tags` file for tagging

Similarily to official
[drone-docker](https://github.com/drone-plugins/drone-docker) plugin you can use
`.tags` file to embed some custom logic for creating tags for an image.

```yaml
kind: pipeline
name: default

steps:
- name: build
  image: golang
  commands:
      - go get 
      - go build
      - make versiontags > .tags
- name: publish
  image: registry.odit.services/library/drone-kaniko
  settings:
    registry: registry.example.com 
    repo: registry.example.com/example-project
    # tags: ${DRONE_COMMIT_SHA} <= it must be left undefined 
    username:
      from_secret: docker-username
    password:
      from_secret: docker-password
```

## Auto tag

Set `auto_tag: true`.

```yaml
kind: pipeline
name: default

steps:
- name: build
  image: golang
  commands:
      - go get 
      - go build
- name: publish
  image: registry.odit.services/library/drone-kaniko
  settings:
    registry: registry.example.com 
    repo: registry.example.com/example-project
    auto_tag: true # higher priority then .tags file
    # tags: ${DRONE_COMMIT_SHA} <= it must be left undefined to use auto_tag
    username:
      from_secret: docker-username
    password:
      from_secret: docker-password
```